<?xml version='1.0' encoding='UTF-8'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.0">
  <xsl:template name="genPath">
    <xsl:param name="prevPath"/>
    <xsl:variable name="currPath" select="concat('/',name(),'[', count(preceding-sibling::*[name() = name(current())])+1,']',$prevPath)"/>
    <xsl:for-each select="parent::*">
      <xsl:call-template name="genPath">
        <xsl:with-param name="prevPath" select="$currPath"/>
      </xsl:call-template>
    </xsl:for-each>
    <xsl:if test="not(parent::*)">
      <xsl:value-of select="$currPath"/>
    </xsl:if>
  </xsl:template>
  <xsl:strip-space elements="*"/>
  <xsl:template match="/">
    <warnings>
      <xsl:apply-templates select="//@*|node()"/>
    </warnings>
  </xsl:template>
  <xsl:template match="@*|text()"/>
  <xsl:template match="Package/@xsi:noNamespaceSchemaLocation[.='LIXI-CAL-2_6_24-Annotated.xsd']">
    <updated>
      <xsl:attribute name="name">xsi:noNamespaceSchemaLocation</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">LIXI-CAL-2_6_24-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="update">LIXI-CAL-2_6_25-Annotated.xsd</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Think Tank Group Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Think Tank Group Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Money Quest Australia Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Money Quest Australia Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Faraday West and Co Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Faraday West and Co Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Money Quest Australia Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Money Quest Australia Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/CompanyApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='RedZed']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">RedZed</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Think Tank Group Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Think Tank Group Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Money Quest Australia Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Money Quest Australia Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Faraday West and Co Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Faraday West and Co Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='Rate Money Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Rate Money Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Liability/AccountNumber/@OtherFIName[.='RedZed']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">RedZed</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Think Tank Group Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Think Tank Group Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Money Quest Australia Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Money Quest Australia Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Faraday West and Co Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Faraday West and Co Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='Rate Money Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Rate Money Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FeaturesSelected/OffsetAccount/AccountNumber/@OtherFIName[.='RedZed']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">RedZed</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Think Tank Group Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Think Tank Group Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Money Quest Australia Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Money Quest Australia Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Faraday West and Co Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Faraday West and Co Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='Rate Money Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Rate Money Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/FundsDisbursement/AccountNumber/@OtherFIName[.='RedZed']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">RedZed</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Think Tank Group Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Think Tank Group Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Money Quest Australia Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Money Quest Australia Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Faraday West and Co Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Faraday West and Co Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='Rate Money Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Rate Money Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/LoanDetails/ProposedRepayment/FromAccount/@OtherFIName[.='RedZed']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">RedZed</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/@Description[.='TrustBeneficialInterest']">
    <removed>
      <xsl:attribute name="name">Description</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">TrustBeneficialInterest</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@Type">
        <updated>
          <xsl:attribute name="name">Type</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@Type">
            <xsl:attribute name="value">
              <xsl:value-of select="../@Type"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">TrustBeneficialInterest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">Type</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">TrustBeneficialInterest</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Think Tank Group Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Think Tank Group Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Money Quest Australia Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Money Quest Australia Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Faraday West and Co Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Faraday West and Co Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='Rate Money Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Rate Money Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/NonRealEstateAsset/FinancialAsset/AccountNumber/@OtherFIName[.='RedZed']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">RedZed</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Think Tank Group Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Think Tank Group Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Money Quest Australia Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Money Quest Australia Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Faraday West and Co Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Faraday West and Co Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Rate Money Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Rate Money Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/PersonApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='RedZed']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">RedZed</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Think Tank Group Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Think Tank Group Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Money Quest Australia Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Money Quest Australia Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Faraday West and Co Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Faraday West and Co Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='Rate Money Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Rate Money Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/Summary/Fee/AccountNumber/@OtherFIName[.='RedZed']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">RedZed</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Think Tank Group Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Think Tank Group Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Think Tank Group Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Money Quest Australia Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Money Quest Australia Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Money Quest Australia Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Faraday West and Co Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Faraday West and Co Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Faraday West and Co Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='Rate Money Pty Ltd']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">Rate Money Pty Ltd</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">Rate Money Pty Ltd</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/Content/Application/TrustApplicant/ExistingCustomer/AccountNumber/@OtherFIName[.='RedZed']">
    <removed>
      <xsl:attribute name="name">OtherFIName</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">RedZed</xsl:attribute>
      <xsl:attribute name="reason">attribute value moved</xsl:attribute>
    </removed>
    <xsl:choose>
      <xsl:when test="../@FinancialInstitution">
        <updated>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:if test="../@FinancialInstitution">
            <xsl:attribute name="value">
              <xsl:value-of select="../@FinancialInstitution"/>
            </xsl:attribute>
          </xsl:if>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </updated>
      </xsl:when>
      <xsl:otherwise>
        <appended>
          <xsl:attribute name="name">FinancialInstitution</xsl:attribute>
          <xsl:attribute name="type">attribute</xsl:attribute>
          <xsl:attribute name="path">
            <xsl:call-template name="genPath"/>
          </xsl:attribute>
          <xsl:attribute name="update">RedZed</xsl:attribute>
          <xsl:attribute name="reason">attribute value moved</xsl:attribute>
        </appended>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
  <xsl:template match="Package/SchemaVersion/@LIXIVersion[.='2.6.24']">
    <updated>
      <xsl:attribute name="name">LIXIVersion</xsl:attribute>
      <xsl:attribute name="type">attribute</xsl:attribute>
      <xsl:attribute name="path">
        <xsl:call-template name="genPath"/>
      </xsl:attribute>
      <xsl:attribute name="value">2.6.24</xsl:attribute>
      <xsl:attribute name="update">2.6.25</xsl:attribute>
      <xsl:attribute name="reason">enumeration not available</xsl:attribute>
    </updated>
    <xsl:apply-templates select="node()"/>
  </xsl:template>
</xsl:stylesheet>
